pub enum EnchantmentEffectRequirements {
AllOf(&'static [&'static EnchantmentEffectRequirements]),
AnyOf(&'static [&'static EnchantmentEffectRequirements]),
Inverted(&'static EnchantmentEffectRequirements),
EntityProperties {
entity: EnchantmentEntityTarget,
predicate: EntityPredicate,
},
DamageSourceProperties(DamageSourcePredicate),
RandomChance {
chance: &'static LevelBasedValue,
},
MatchTool {
items: Option<EnchantmentItemSet>,
},
Unsupported {
condition: Identifier,
},
}Expand description
Vanilla loot condition subset used by generated enchantment effects.
Variants
AllOf(&'static [&'static EnchantmentEffectRequirements])
AnyOf(&'static [&'static EnchantmentEffectRequirements])
Inverted(&'static EnchantmentEffectRequirements)
EntityProperties
DamageSourceProperties(DamageSourcePredicate)
RandomChance
Fields

chance: &'static LevelBasedValueMatchTool
Fields

items: Option<EnchantmentItemSet>Unsupported
Fields

condition: IdentifierImplementations
Sourceimpl EnchantmentEffectRequirements
impl EnchantmentEffectRequirements
Sourcepub fn matches_item_context(&self, item: ItemRef) -> Option<bool>
pub fn matches_item_context(&self, item: ItemRef) -> Option<bool>
Evaluates the subset of loot conditions supported by Vanilla’s item-only
enchantment context. None keeps unsupported contexts fail-closed.