pub enum EnchantmentValueEffect {
Add {
value: &'static LevelBasedValue,
},
Set {
value: &'static LevelBasedValue,
},
Multiply {
factor: &'static LevelBasedValue,
},
RemoveBinomial {
chance: &'static LevelBasedValue,
},
}Expand description
Vanilla EnchantmentValueEffect.
Variants
Add
Fields

value: &'static LevelBasedValueSet
Fields

value: &'static LevelBasedValueMultiply
Fields

factor: &'static LevelBasedValueRemoveBinomial
Fields

chance: &'static LevelBasedValueImplementations
Sourceimpl EnchantmentValueEffect
impl EnchantmentValueEffect
Sourcepub fn process_without_random(&self, level: i32, input: f32) -> Option<f32>
pub fn process_without_random(&self, level: i32, input: f32) -> Option<f32>
Applies effects that do not require a random source.
remove_binomial is excluded because it requires a random source; use
Self::process_with_random when the component permits random effects.